summaryrefslogtreecommitdiffstats
path: root/ksayit/src/docbookgenerator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksayit/src/docbookgenerator.cpp')
-rw-r--r--ksayit/src/docbookgenerator.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksayit/src/docbookgenerator.cpp b/ksayit/src/docbookgenerator.cpp
index a6f8a72..d9ab809 100644
--- a/ksayit/src/docbookgenerator.cpp
+++ b/ksayit/src/docbookgenerator.cpp
@@ -105,10 +105,10 @@ void DocbookGenerator::writeTitleOfBook(TQTextStream &doc, ListViewInterface *it
if ( whoAmI != "BookInfo" )
return;
- // Documents title is stored in root element (tqparent of BookInfo)
- ListViewInterface *tqparent = static_cast<ListViewInterface*>(item->tqparent());
- if ( tqparent ){
- TQString title = tqparent->text(0);
+ // Documents title is stored in root element (parent of BookInfo)
+ ListViewInterface *parent = static_cast<ListViewInterface*>(item->parent());
+ if ( parent ){
+ TQString title = parent->text(0);
// add node to document
doc << "<Title>" << title << "</Title>" << endl;